[![Build Status](https://travis-ci.com/Group23andMe/cs107-FinalProject.svg?token=BUKa7wnCnGGE3CREZbzR&branch=master)](https://travis-ci.com/Group23andMe/cs107-FinalProject)

[![codecov](https://codecov.io/gh/Group23andMe/cs107-FinalProject/branch/master/graph/badge.svg?token=6ZFFBKE2H3)](https://codecov.io/gh/Group23andMe/cs107-FinalProject)

# Group 23 Final Project
## Members
* Omead Eftekhari
* Drew Pendergrass
* Saul Soto
* Ryan Liu

## Installation
Install our package by running the following command into the bash:
```
pip install AutoDiffGroup23andMe
```

## Documentation
https://github.com/Group23andMe/cs107-FinalProject/blob/master/docs/documentation.ipynb


## Broader Impact
Auto-differentiation is a powerful tool, which powers the optimization capabilities of our package. Although the optimization of purely mathematical functions is not likely to be a cause of concern, the application of these algorithms to real life data has potential to be misused and misinterpretted, especially when this data is biased or the optimizations are used for purposes have negative externalities. We encourage individuals who apply this optimization software to data to evaluate what are some potential causes of bias and to keep algorithmic fairness in mind.

## Software Inclusivity
Since this project is our submission to the CS107 final project and its main purpose is to showcase the abilities of auto-differentiation, we would like to keep the master branch of this repo static after submission. However, anyone is welcome to clone this project if they want to build on the code base themselves. We encourage people who clone this repo to also make their extensions open-source, so that others can learn from their code. All the developers of this package used their personal Github to contribute and will receive notifications about any questions or issues, and all of us are happy to help in any way that we can. In the event that this package becomes active, we are committed to reviewing and accepting pull requests anonymously and respectfully. If you feel that your contribution is unfairly ignored, please raise the issue with us. We acknowlege a history of racial and gender-based inequality in software development and will do our best to confront and correct this issue.

We recognize that there may be barriers for certain interested individuals that may not have access to GitHub or Pypi or the necessary resources to clone or run this package on their own computers, in which case we encourage you to utilize free online resources such as Google Colab. A tutorial of how to clone and install packages all on Google Colab/Google Drive is linked here: https://www.kdnuggets.com/2018/02/google-colab-free-gpu-tutorial-tensorflow-keras-pytorch.html/2
